## ----setup, include=FALSE, results="hide"--------------------------------
knitr::opts_chunk$set(echo = TRUE, fig.width=7,fig.height=5,echo=TRUE)

## ----library-------------------------------------------------------------
library(Mercator)
#suppressWarnings( suppressMessages( library(Thresher) ))

## ----data----------------------------------------------------------------
filename <- system.file("Examples/Mercator_Test_Data.csv", package="Mercator")
my.data <- read.csv(filename, header=TRUE)
dim(my.data)

## ------------------------------------------------------------------------
my.data <- as.matrix(my.data)
my.rows <- c(1:length(my.data[,1]))
my.rows <- paste("C", my.rows, sep = "")
my.rows <- data.frame(my.rows)
my.binmat <- BinaryMatrix(my.data, , my.rows)
summary(my.binmat)

## ------------------------------------------------------------------------
my.binmat <- t(my.binmat)
summary(my.binmat)

## ----duplicateFeatures---------------------------------------------------
my.binmat <- removeDuplicateFeatures(my.binmat)
summary(my.binmat)

## ------------------------------------------------------------------------
length(my.binmat@info$notUsed)

## ------------------------------------------------------------------------
length(my.binmat@info$redundant)

## ----thresher------------------------------------------------------------
set.seed(21348)
my.binmat <- threshLGF(my.binmat, cutoff=0.3)
summary(my.binmat)

## ----delta, fig.cap="Histogram of weight vectors."-----------------------
Delta <- my.binmat@thresher@delta
hist(Delta, breaks=20, main="", xlab="Weight")
abline(v=0.3, col='red')

## ----pcdim---------------------------------------------------------------
my.binmat@reaper@pcdim
my.binmat@reaper@nGroups

## ----pcVis-1, fig.cap="Auer-Gervini plot."-------------------------------
plot(my.binmat@reaper@ag)
abline(h=my.binmat@reaper@pcdim, col="blue")
abline(h=my.binmat@reaper@nGroups, col="green")
abline(h=8, col="orange")

## ----pcVis-2, fig.cap="Scree plot."--------------------------------------
screeplot(my.binmat@reaper)
abline(h=my.binmat@reaper@pcdim, col="blue")
abline(h=my.binmat@reaper@nGroups, col="green")
abline(h=8, col="orange")

## ----kk------------------------------------------------------------------
kk <- 8

## ----distance, echo=TRUE-------------------------------------------------
jacc.Vis <- Mercator(my.binmat, "jaccard", "hclust", K=kk)

## ----jacc-hist-----------------------------------------------------------
hist(jacc.Vis, 
     xlab="Jaccard Distance", main="Histogram of Distances")

## ----jacc-hclust---------------------------------------------------------
plot(jacc.Vis@view[[1]], col="black", pch=jacc.Vis@symv)

## ----jacc-heat-----------------------------------------------------------
jacc.Vis <- addVisualization(jacc.Vis, "heat")
plot(jacc.Vis@view[[2]], col=jacc.Vis@colv, pch=jacc.Vis@symv)

## ----jacc-tsne5----------------------------------------------------------
par(pty="s")
jacc.Vis <- addVisualization(jacc.Vis, "tsne", 
            perplexity=5, 
            xlab="T1", ylab="T2")
plot(jacc.Vis@view[[3]]$Y, col=jacc.Vis@colv, pch=jacc.Vis@symv,
     main="t-SNE; Jaccard Distance; perplexity=5")

## ----jacc-tsne10---------------------------------------------------------
jacc.Vis <- addVisualization(jacc.Vis, "tsne", 
            perplexity=10,
            xlab="T1", ylab="T2")
plot(jacc.Vis@view[[3]]$Y, col=jacc.Vis@colv, pch=jacc.Vis@symv,
     main="t-SNE; Jaccard Distance; perplexity=10")
par(pty="m")

## ----jacc-mds1-----------------------------------------------------------
jacc.Vis <- addVisualization(jacc.Vis, "mds")
plot(jacc.Vis@view[[4]], col=jacc.Vis@colv, pch=jacc.Vis@symv,
      main="MDS; Jaccard Distance", xlab="PC1", ylab="PC2")

## ----downsample----------------------------------------------------------
X <- jacc.Vis
N <- as.matrix(X@distance)
set.seed(87530)
P <- downsample(40, N, 0.1)
J <- jacc.Vis[P]
J <- addVisualization(J, "tsne", perplexity=5)
par(pty="s")
plot(J@view[[3]]$Y, col=J@colv, pch=J@symv, main="Down-sampled t-SNE Plot",
     xlab="T1", ylab="T2")
par(pty="m")

## ----igraph, eval=FALSE--------------------------------------------------
#  set.seed(10967)
#  J <- addVisualization(J, "mds")
#  J <- addVisualization(J, "graph")
#  G <- J@view[["graph"]]
#  
#  V <- igraph::vertex_attr(G$graph)
#  
#  plot(G$graph, layout=G$layouts[["mds"]])
#  
#  plot(G$graph, layout=G$layouts[["nicely"]],
#       main="Graphical View of Down-sampled Jaccard Distance Matrix",
#       xlim=c(-1,1))
#  
#  
#  plot(G$graph, layout=G$layouts[["tsne"]], main="T-SNE Layout")

## ----cluster1Identity----------------------------------------------------
my.clust <- getClusters(jacc.Vis)
tab <- table(my.clust)
tab

## ------------------------------------------------------------------------
C <- my.binmat@columnInfo
Cl4 <- C[my.clust == 4 ,]
Cl4

